@@ -1692,10 +1692,10 @@ void qxgeditMainForm::viewRandomize (void)
 	if (m_pMasterMap == NULL)
 		return;
 
-	int p = 100;
+	float p = 100.0f;
 
 	if (m_pOptions) {
-		p = m_pOptions->iRandomizePerct;
+		p = m_pOptions->fRandomizePercent;
 		if (m_pOptions->bConfirmReset) {
 			QString sText;
 			switch (m_ui.MainTabWidget->currentIndex()) {
@@ -1841,11 +1841,11 @@ void qxgeditMainForm::helpAbout (void)
 	sText += "<b>" QXGEDIT_TITLE " - " + tr(QXGEDIT_SUBTITLE) + "</b><br />\n";
 	sText += "<br />\n";
 	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
-	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
+//	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
 #ifdef CONFIG_DEBUG
 	sText += "<small><font color=\"red\">";
 	sText += tr("Debugging option enabled.");
-	sText += "</font></small><br />";
+	sText += "</font></small><br />\n";
 #endif
 	sText += "<br />\n";
 	sText += tr("Website") + ": <a href=\"" QXGEDIT_WEBSITE "\">" QXGEDIT_WEBSITE "</a><br />\n";
